@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Catalogue.py
-Version : 1.0.1
+Version : 1.1.1
 Author  : Stefano Covino
-Date    : 05/02/2011
+Date    : 29/07/2015
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -14,8 +14,8 @@ Remarks :
 
 History : (28/03/2011) First version.
         : (05/02/2012) Better path management.
-
-
+        : (23/07/2015) python3 comparison.
+        : (29/07/2015) python3 porting.
 """
 
 import os, os.path
@@ -35,8 +35,9 @@ class AGNOptRefStars:
     catpath = os.path.join(basepath,'SRPData','Catalogues','AGNOptRefStars',filename)
     # Catalogue entries
     class CatEntries:
-        def __init__ (self,(id,ra,dec,v,ev,r,er,i,ei)):
+        def __init__ (self, xxx_todo_changeme):
             # Id
+            (id,ra,dec,v,ev,r,er,i,ei) = xxx_todo_changeme
             self.Id = id
             # Coord
             coord = AstroCoordInput(ra,dec)
@@ -62,15 +63,10 @@ class AGNOptRefStars:
             msg = msg + "%10.3f\t%9.3f\t" % (self.R, self.eR)
             msg = msg + "%10.3f\t%9.3f" % (self.I, self.eI)            
             return msg
-            
-            
-        def __cmp__ (self, other):
-            if self.R < other.R:
-                return -1
-            elif self.R == other.R:
-                return 0
-            else:
-                return 1
+        
+
+        def __lt__ (self, other):
+            return self.R < other.R
     
     
     def __init__ (self, ra, dec, radius=1.0, epoch=2000.0):
@@ -82,7 +78,7 @@ class AGNOptRefStars:
         
         
     def GetData(self):
-        f = file(self.catpath)
+        f = open(self.catpath)
         data = f.readlines()
         f.close()
         if data != None:
