@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Catalogue.py
-Version : 1.0.2
+Version : 1.1.1
 Author  : Stefano Covino
-Date    : 05/02/2012
+Date    : 29/07/2015
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -15,8 +15,8 @@ Remarks :
 History : (29/09/2010) First version.
         : (16/10/2010) Output better suited for skycat.
         : (05/02/2012) Better path management.
-
-
+        : (23/07/2015) python3 comparison.
+        : (29/07/2015) python3 porting.
 """
 
 import os, os.path
@@ -36,8 +36,9 @@ class BrightStars:
     catpath = os.path.join(basepath,'SRPData','Catalogues','BrightStarCatalogue',filename)
     # Catalogue entries
     class CatEntries:
-        def __init__ (self,(id,name,ra,dec,mag,dflag,cls,spt)):
+        def __init__ (self, xxx_todo_changeme):
             # Id & name
+            (id,name,ra,dec,mag,dflag,cls,spt) = xxx_todo_changeme
             self.Id = id
             self.Name = name
             # Coord
@@ -61,16 +62,13 @@ class BrightStars:
             msg = msg + "%3s\t%6s\t" % (self.DoubleFlag, self.Cls)
             msg = msg + "%7s" % (self.SpType)
             return msg
-            
-            
-        def __cmp__ (self, other):
-            if self.Mag < other.Mag:
-                return -1
-            elif self.Mag == other.Mag:
-                return 0
-            else:
-                return 1
-    
+
+
+        def __lt__ (self, other):
+            return self.Mag < other.Mag
+
+
+
     
     def __init__ (self, ra, dec, radius=1.0, epoch=2000.0):
         inpcoord = AstroCoordInput(ra,dec,inp_equinox=epoch)
@@ -81,7 +79,7 @@ class BrightStars:
         
         
     def GetData(self):
-        f = file(self.catpath)
+        f = open(self.catpath)
         data = f.readlines()
         f.close()
         if data != None:
