@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Catalogue.py
-Version : 1.0.7
+Version : 1.0.11
 Author  : Stefano Covino
-Date    : 26/07/2013
+Date    : 14/05/2019
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -20,6 +20,10 @@ History : (29/09/2010) First version.
         : (11/06/2011) USNOB1 catalogue.
         : (06/05/2013) SDSS catalogue.
         : (26/07/2013) APASS catalogue.
+        : (29/07/2015) Smith et al. ugriz catalogue.
+        : (14/02/2016) SkyBot query.
+        : (17/02/2016) IGAIA.
+        : (14/05/2019) SDSS.
 """
 
 # Available catalogues
@@ -33,6 +37,10 @@ USC = "USNO-A2 Catalogue"
 NCC = "NIR Catalogue Collection"
 AGNOPT = "AGN Optical Standard Stars"
 SDSS = "Sloan Digital Sky Survey"
+SMI = "Smith et al. ugriz Standard Stars"
+SKB = "SkyBot Minor Planet"
+IGAIA = "Initial GAIA catalogue"
+SMBD = "Simbad catalogue"
 
-SRPCatalDict = {'APS' : APS, 'BSC' : BSC, 'TMC' : TMC, 'SSC' : SSC, 'AWC' : AWC, 'USB' : USB, 'USC' : USC, 'NCC' : NCC, 'AGNOPT' : AGNOPT, 'SDSS' : SDSS}
+SRPCatalDict = {'APS' : APS, 'BSC' : BSC, 'TMC' : TMC, 'SSC' : SSC, 'AWC' : AWC, 'USB' : USB, 'USC' : USC, 'NCC' : NCC, 'AGNOPT' : AGNOPT, 'SKB' : SKB, 'SDSS' : SDSS, 'SMI' : SMI, 'IGAIA' : IGAIA, 'SMBD' : SMBD}
 
