@@ -17,7 +17,7 @@ History : (21/03/2011) First version.
 """
 
 
-import ExtConstants
+from . import ExtConstants
 import numpy
 
 
